@@ -20,7 +20,7 @@ package
 package PkgConfig;
 
 #First two digits are Perl version, second two are pkg-config version
-our $VERSION = '0.08926';
+our $VERSION = '0.10026';
 
 $VERSION =~ /([0-9]{2})$/;
 my $compat_version = $1;
@@ -90,6 +90,24 @@ if($ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION}) {
         /usr/lib/64/pkgconfig /usr/share/pkgconfig
     );
 
+} elsif($^O eq 'linux' and -f '/etc/gentoo-release') {
+    # OK, we're running on Gentoo
+
+    # Fetch ptrsize value
+    my $ptrsize = $Config{ptrsize};
+
+    # Are we running on 64 bit system?
+    if ($ptrsize eq 8) {
+        # We do
+        @DEFAULT_SEARCH_PATH = qw!
+          /usr/lib64/pkgconfig/ /usr/share/pkgconfig/
+        !;
+    } else {
+        # We're running on a 32 bit system (hopefully)
+        @DEFAULT_SEARCH_PATH = qw!
+          /usr/lib/pkgconfig/ /usr/share/pkgconfig/
+        !;
+    }
 } elsif($^O =~ /^(gnukfreebsd|linux)$/ && -r "/etc/debian_version") {
 
     my $arch;
@@ -1051,6 +1069,8 @@ GetOptions(
 
     'silence-errors' => \my $SilenceErrors,
     'print-errors' => \my $PrintErrors,
+    'errors-to-stdout' => \my $ErrToStdOut,
+    'short-errors'     => \my $ShortErrors,
     
     'define-variable=s', => \my %UserVariables,
     
@@ -1109,10 +1129,20 @@ if($PrintRealVersion) {
 if($PrintErrors) {
     $quiet_errors = 0;
 }
+
 if($SilenceErrors) {
     $quiet_errors = 1;
 }
 
+# This option takes precedence over all other options
+# be it:
+# --silence-errors
+# or
+# --print-errors
+if ($ErrToStdOut) {
+ $quiet_errors = 2;
+}
+
 my $WantFlags = ($PrintCflags || $PrintLibs || $PrintLibsOnlyL || $PrintCflagsOnlyI || $PrintCflagsOnlyOther || $PrintLibsOnlyOther || $PrintLibsOnlyl || $PrintVersion);
 
 if($WantFlags) {
@@ -1164,7 +1194,14 @@ if($AtLeastVersion) {
 my $o = PkgConfig->find(\@FINDLIBS, %pc_options);
 
 if($o->errmsg) {
-    print STDERR $o->errmsg unless $quiet_errors;
+    # --errors-to-stdout
+    if ($quiet_errors eq 2) {
+        print STDOUT $o->errmsg;
+    # --print-errors
+    } elsif ($quiet_errors eq 1) {
+        print STDERR $o->errmsg;
+    }
+    # --silence-errors
     exit(1);
 }
 
@@ -1395,10 +1432,17 @@ arguments
 
 =head4 --print-errors
 
-This makes all errors noisy and takes precedence over
+Print errors to STDERR and takes precedence over
 C<--silence-errors>
 
+=head4 --short-errors
 
+Ignored, but recognized for compatability.
+
+=head4 --errors-to-stdout
+
+Print errors to STDOUT and takes precedence over
+C<--print-errors>
 
 =head3 ENVIRONMENT
 
